#
# spec file for package ghc-th-compat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name th-compat
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.6
Release:        1.5
Summary:        Backward- (and forward-)compatible Quote and Code types
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
%endif

%description
This package defines a "Language.Haskell.TH.Syntax.Compat" module, which
backports the 'Quote' and 'Code' types to work across a wide range of
'template-haskell' versions. The 'makeRelativeToProject' utility is also
backported. On recent versions of 'template-haskell' (2.17.0.0 or later), this
module simply reexports definitions from "Language.Haskell.TH.Syntax".
Refer to the Haddocks for "Language.Haskell.TH.Syntax.Compat" for examples of
how to use this module.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Dec  5 2024 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.6.
  [#]## 0.1.6 [2024.12.05]
  * Drop support for pre-8.0 versions of GHC.
* Tue Apr 30 2024 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.5 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Apr 20 2024 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Mar 19 2024 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.5.
  [#]## 0.1.5 [2024.03.19]
  * Support building with `template-haskell-2.22.*` (GHC 9.10).
* Mon Jan 22 2024 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.4 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Aug  7 2023 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.4 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Mar 10 2023 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Mar  4 2023 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Jul 23 2022 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.4.
  [#]## 0.1.4 [2022.07.23]
  * Backport the `getPackageRoot` and `makeRelativeToProject` functions
    introduced in `template-haskell-2.19.0.0` (GHC 9.4).
  * Implement `qGetPackageRoot` in the `Quasi` instance for `QuoteToQuasi` when
    building with `template-haskell-2.19.0.0` (GHC 9.4) or later.
* Sat May  7 2022 Peter Simons <psimons@suse.com>
- Update th-compat to version 0.1.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Sep  3 2021 psimons@suse.com
- Update th-compat to version 0.1.3.
  [#]## 0.1.3 [2021.08.29]
  * Implement `qGetDoc` and `qPutDoc` in the `Quasi` instance for `QuoteToQuasi`.
  * Add `expToSplice`.
* Fri Mar 12 2021 psimons@suse.com
- Update th-compat to version 0.1.2.
  [#]## 0.1.2 [2021.03.12]
  * Add `bindSplice`, `bindSplice_`, `examineSplice`, `joinSplice`,
    `hoistSplice`, `liftSplice`, and `unTypeSplice` to
    `Language.Haskell.TH.Syntax.Compat`.
* Mon Feb  8 2021 psimons@suse.com
- Update th-compat to version 0.1.1.
  [#]## 0.1.1 [2021.02.07]
  * Mark `Language.Haskell.TH.Syntax.Compat` as `Trustworthy`.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Sep 30 2020 psimons@suse.com
- Add th-compat at version 0.1.
